import weka.core.jvm as jvm
#from weka.core.converters import Loader, Saver
jvm.start()

import weka.core.converters as converters

"""You can load and save datasets of various data formats using the Loader and Saver classes."""
loader = converters.Loader(classname="weka.core.converters.ArffLoader")
dataset = loader.load_file("C:\\Users\\Anna\Dropbox\\LBI\\2017-LBI\\data1\\census.arff")

"Alternative approach: loader/saver based on the file extension"
dataset2 = converters.load_any_file("C:\\Users\\Anna\Dropbox\\LBI\\2017-LBI\\data1\\census.arff")
converters.save_any_file(dataset2, "C:\\Users\\Anna\Dropbox\\LBI\\2017-LBI\\data1\\census.csv")

print('--------------DATA----------------')
print('number of attributes')
natts = dataset.num_attributes
print(natts)
print()


print('number of instances')
print(dataset.num_instances)
print()

print('Take a specific row: in this case the first row')
print(dataset.get_instance(0))
print()

print('--------------DATA2----------------')
print(dataset2.num_attributes)
print(dataset2.num_instances)
print(dataset2.get_instance(0))

print()
print('Take an attribute and enumerate its distinct values')
last = dataset.attribute(natts-1)
for v in last.values:
    print(v)
print()

print('--------------FILTER----------------')

from weka.filters import Filter

remove = Filter(classname="weka.filters.unsupervised.attribute.Remove", options=["-R", "1"])
remove.inputformat(dataset)         # let the filter know about the type of data to filter
filtered = remove.filter(dataset)   # filter the data
print('N. Attributes of filtered dataset: ', filtered.num_attributes)                     
print('N. instances of filtered dataset: ', filtered.num_instances)  
print(filtered.get_instance(0))

print()
print('--------------Classifier----------------')


from weka.classifiers import Classifier, Evaluation
from weka.core.classes import Random

dataset.class_is_last()   # set class attribute
cls = Classifier(classname="weka.classifiers.trees.J48")
cls.options=["-M", "200"]
cls.build_classifier(dataset)
print('The obtained tree  -- the model')
print(cls) 
evaluation = Evaluation(dataset)                     # initialize with priors
evaluation.crossvalidate_model(cls, dataset, 10, Random(42))  
print(evaluation.summary())



'''Prediction of an instance: returns the index of the enumerated 
value. In case of numerical prediction the returned values is the 
final prediction and not the index.'''
att_class = dataset.class_attribute
print(att_class)
        
for index, inst in enumerate(dataset):
    pred = cls.classify_instance(inst)
    dist = cls.distribution_for_instance(inst)
    print ("predicttion: ", pred)
    print(str(index+1) + ": label= " + att_class.value(int(pred)) + ", class distribution= " + str(dist))
    break


print("------ASSOCIATION RULES---")
from weka.associations import Associator

baskets =  converters.load_any_file('C:\\Users\\Anna\\Desktop\\Weka.3.7.12.Light\\Weka.3.7.12.Light\\data\\supermarket.arff');

ar = Associator(classname="weka.associations.FPGrowth")
ar.options=["-N", "20", "-U", "1", "-M","0.01", "D", "0.05", "-T","0","-0.8"]
ar.build_associations(baskets)
print(ar)

